@@ -188,13 +188,13 @@ Parsec</translatorcomment>
 <context>
     <name>RColor</name>
     <message>
-        <location filename="../src/core/RColor.cpp" line="+287"/>
+        <location filename="../src/core/RColor.cpp" line="+288"/>
         <source>By Layer</source>
         <translatorcomment>--exact match--
 --file: qcadguiqt_it.ts--
 Da Layer
 Scegli layer nella cartella</translatorcomment>
-        <translation>Da Layer</translation>
+        <translation>Da livello</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -524,8 +524,8 @@ Inserisci l&apos;angolo della linea di quota:</translatorcomment>
         <translation>Attributi</translation>
     </message>
     <message>
-        <location filename="../src/core/REntity.cpp" line="+87"/>
-        <location filename="../src/core/RObject.cpp" line="+66"/>
+        <location filename="../src/core/REntity.cpp" line="+91"/>
+        <location filename="../src/core/RObject.cpp" line="+67"/>
         <source>Type</source>
         <translatorcomment>--exact match--
 --file: liferea-1.8-rc1.it.po--
@@ -547,11 +547,11 @@ Tipo Ordinata</translatorcomment>
 &amp;Layer
 Livelli
 Lista Layer</translatorcomment>
-        <translation>Layer</translation>
+        <translation>Livello</translation>
     </message>
     <message>
         <location line="+1"/>
-        <location filename="../src/core/RLayer.cpp" line="+99"/>
+        <location filename="../src/core/RLayer.cpp" line="+102"/>
         <source>Linetype</source>
         <translatorcomment>--exact match--
 --file: LinetypeSettings_it.ts--
@@ -626,7 +626,7 @@ Colore G&amp;riglia:</translatorcomment>
     </message>
     <message>
         <location filename="../src/core/RObject.cpp" line="-1"/>
-        <location filename="../src/core/RPropertyTypeId.cpp" line="+108"/>
+        <location filename="../src/core/RPropertyTypeId.cpp" line="+151"/>
         <source>Custom</source>
         <translation>Personalizzato</translation>
     </message>
@@ -640,6 +640,11 @@ Colore G&amp;riglia:</translatorcomment>
         <source>Protected</source>
         <translation>Protetta</translation>
     </message>
+    <message>
+        <location line="+1"/>
+        <source>Selected</source>
+        <translation>Selezionato</translation>
+    </message>
     <message>
         <location filename="../src/core/REntity.cpp" line="+2"/>
         <location filename="../src/core/RLayout.cpp" line="+1"/>
@@ -685,12 +690,12 @@ Colore G&amp;riglia:</translatorcomment>
     <message>
         <location line="+1"/>
         <source>Font Name</source>
-        <translation>Nome del font</translation>
+        <translation>Nome carattere</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Text Height</source>
-        <translation>Altezza Testo</translation>
+        <translation>Altezza testo</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -764,6 +769,7 @@ Colore G&amp;riglia:</translatorcomment>
     <message>
         <location filename="../src/core/RBlock.cpp" line="-6"/>
         <location filename="../src/core/RLayer.cpp" line="-8"/>
+        <location filename="../src/core/RLayerState.cpp" line="+46"/>
         <location filename="../src/core/RLayout.cpp" line="-24"/>
         <source>Name</source>
         <translation>Nome</translation>
@@ -801,7 +807,7 @@ Colore G&amp;riglia:</translatorcomment>
     <message>
         <location line="+1"/>
         <source>Snappable</source>
-        <translation>Agganciabile</translation>
+        <translation>Scattante</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -853,7 +859,7 @@ Colore G&amp;riglia:</translatorcomment>
         <translation type="vanished">Margini di stampa</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlockReferenceData.cpp" line="+627"/>
+        <location filename="../src/core/RBlockReferenceData.cpp" line="+655"/>
         <source>Circular (recursive) block referencing detected:</source>
         <translation>È stato rilevato un riferimento circolare (ricorsivo) blocco:</translation>
     </message>
@@ -866,7 +872,7 @@ Colore G&amp;riglia:</translatorcomment>
 <context>
     <name>RGuiAction</name>
     <message>
-        <location filename="../src/core/RGuiAction.cpp" line="+184"/>
+        <location filename="../src/core/RGuiAction.cpp" line="+186"/>
         <source>Requires selection</source>
         <translatorcomment>--google--</translatorcomment>
         <translation>Richiede selezione</translation>
@@ -911,7 +917,7 @@ Colore G&amp;riglia:</translatorcomment>
 --file: qcadguiqt_it.ts--
 Da Layer
 Scegli layer nella cartella</translatorcomment>
-        <translation type="vanished">Da Layer</translation>
+        <translation type="vanished">Per livello</translation>
     </message>
     <message>
         <source>By Block</source>
@@ -1090,7 +1096,7 @@ Margine (Ingrandita)</translatorcomment>
     <message>
         <location filename="../src/core/RLinetypePattern.cpp" line="+856"/>
         <source>By Layer</source>
-        <translation>Da Layer</translation>
+        <translation>Da livello</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -1300,7 +1306,7 @@ Margine (Ingrandita)</translatorcomment>
 --file: qcadguiqt_it.ts--
 Da Layer
 Scegli layer nella cartella</translatorcomment>
-        <translation>Da Layer</translation>
+        <translation>Da livello</translation>
     </message>
     <message>
         <location line="+1"/>
