@@ -11,7 +11,7 @@
     <message>
         <location line="+3"/>
         <source>Inch</source>
-        <translation>Inč</translation>
+        <translation>Palec</translation>
     </message>
     <message>
         <location line="+3"/>
@@ -46,7 +46,7 @@
     <message>
         <location line="+3"/>
         <source>Microinch</source>
-        <translation>Mikroinč</translation>
+        <translation>Mikropalec</translation>
     </message>
     <message>
         <location line="+3"/>
@@ -56,7 +56,7 @@
     <message>
         <location line="+3"/>
         <source>Yard</source>
-        <translation>Yard</translation>
+        <translation>Jard</translation>
     </message>
     <message>
         <location line="+3"/>
@@ -112,14 +112,14 @@
 <context>
     <name>RColor</name>
     <message>
-        <location filename="../src/core/RColor.cpp" line="+287"/>
+        <location filename="../src/core/RColor.cpp" line="+288"/>
         <source>By Layer</source>
         <translation>Po plasti</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>By Block</source>
-        <translation>Po elementu</translation>
+        <translation>Po zbiru</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -174,12 +174,12 @@
     <message>
         <location line="+1"/>
         <source>Dark Cyan</source>
-        <translation>Temno cijan</translation>
+        <translation>Temno sinja</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Dark Magenta</source>
-        <translation>Temno mangenta</translation>
+        <translation>Temno škrlatna</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -227,12 +227,12 @@
     <message>
         <location line="+1"/>
         <source>Linetype Scale</source>
-        <translation>Povečava tipa črte</translation>
+        <translation>Gostota črte</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Dimension Font</source>
-        <translation>Pisava kotiranj</translation>
+        <translation>Pisava kotiranja</translation>
     </message>
 </context>
 <context>
@@ -240,7 +240,7 @@
     <message>
         <location filename="../src/core/RBlockReferenceEntity.cpp" line="+92"/>
         <source>Block</source>
-        <translation>Element</translation>
+        <translation>Zbir</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -250,12 +250,12 @@
         <location line="+1"/>
         <location line="+1"/>
         <source>Position</source>
-        <translation>Pozicija</translation>
+        <translation>Postavitev</translation>
     </message>
     <message>
         <location filename="../src/core/RBlock.cpp" line="+65"/>
         <source>Pixel Unit</source>
-        <translation type="unfinished"></translation>
+        <translation>Enota kot slikovna točka</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -342,28 +342,28 @@
     <message>
         <location line="+1"/>
         <source>Column Spacing</source>
-        <translation>Razmak stolpcev</translation>
+        <translation>Razmik stolpcev</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Row Spacing</source>
-        <translation>Razmak vrstic</translation>
+        <translation>Razmik vrstic</translation>
     </message>
     <message>
         <location line="+3"/>
         <source>Attributes</source>
-        <translation type="unfinished"></translation>
+        <translation>Značilke</translation>
     </message>
     <message>
-        <location filename="../src/core/REntity.cpp" line="+87"/>
-        <location filename="../src/core/RObject.cpp" line="+66"/>
+        <location filename="../src/core/REntity.cpp" line="+91"/>
+        <location filename="../src/core/RObject.cpp" line="+67"/>
         <source>Type</source>
-        <translation>Tip</translation>
+        <translation>Vrsta</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Block ID</source>
-        <translation>ID elementa</translation>
+        <translation>ID zbira</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -372,14 +372,14 @@
     </message>
     <message>
         <location line="+1"/>
-        <location filename="../src/core/RLayer.cpp" line="+99"/>
+        <location filename="../src/core/RLayer.cpp" line="+102"/>
         <source>Linetype</source>
-        <translation>Tip črte</translation>
+        <translation>Vrsta črte</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Linetype Scale</source>
-        <translation>Povečava tipa črte</translation>
+        <translation>Gostota črte</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -437,7 +437,7 @@
     </message>
     <message>
         <location filename="../src/core/RObject.cpp" line="-1"/>
-        <location filename="../src/core/RPropertyTypeId.cpp" line="+108"/>
+        <location filename="../src/core/RPropertyTypeId.cpp" line="+151"/>
         <source>Custom</source>
         <translation>Po meri</translation>
     </message>
@@ -451,6 +451,11 @@
         <source>Protected</source>
         <translation>Zaščiteno</translation>
     </message>
+    <message>
+        <location line="+1"/>
+        <source>Selected</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../src/core/REntity.cpp" line="+2"/>
         <location filename="../src/core/RLayout.cpp" line="+1"/>
@@ -481,12 +486,12 @@
         <location line="+1"/>
         <location line="+1"/>
         <source>Text Position</source>
-        <translation>Pozicija besedila</translation>
+        <translation>Postavitev besedila</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Text</source>
-        <translation>Tekst</translation>
+        <translation>Besedilo</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -521,7 +526,7 @@
     <message>
         <location line="+1"/>
         <source>Italic</source>
-        <translation>Poštevno</translation>
+        <translation>Poševno</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -547,7 +552,7 @@
     <message>
         <location filename="../src/core/RViewportEntity.cpp" line="+2"/>
         <source>Rotation</source>
-        <translation>Rotacija</translation>
+        <translation>Sukanje</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -570,11 +575,12 @@
     <message>
         <location line="+2"/>
         <source>Overall</source>
-        <translation>Globalno</translation>
+        <translation>Celotno</translation>
     </message>
     <message>
         <location filename="../src/core/RBlock.cpp" line="-6"/>
         <location filename="../src/core/RLayer.cpp" line="-8"/>
+        <location filename="../src/core/RLayerState.cpp" line="+46"/>
         <location filename="../src/core/RLayout.cpp" line="-24"/>
         <source>Name</source>
         <translation>Ime</translation>
@@ -582,7 +588,7 @@
     <message>
         <location line="+1"/>
         <source>Hidden</source>
-        <translation>Nevidna</translation>
+        <translation>Skrito</translation>
     </message>
     <message>
         <location filename="../src/core/RLayer.cpp" line="+1"/>
@@ -607,12 +613,12 @@
     <message>
         <location line="+1"/>
         <source>Plottable</source>
-        <translation type="unfinished"></translation>
+        <translation>Izrisljivo</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Snappable</source>
-        <translation type="unfinished"></translation>
+        <translation>Možnost pripenjanja</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -643,7 +649,7 @@
         <location line="+1"/>
         <location line="+1"/>
         <source>Insertion Base</source>
-        <translation>Vključevalna osnova</translation>
+        <translation>Izhodišče vstavitve</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -660,22 +666,22 @@
         <translation>Maks. razširitev</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlockReferenceData.cpp" line="+627"/>
+        <location filename="../src/core/RBlockReferenceData.cpp" line="+655"/>
         <source>Circular (recursive) block referencing detected:</source>
-        <translation>Zaznano krožno (rekurzivno) blokovno sklicevanje:</translation>
+        <translation>Zaznano krožno (rekurzivno) sklicevanje zbirov:</translation>
     </message>
     <message>
         <location line="+2"/>
         <source>Block name:</source>
-        <translation>Ime bloka:</translation>
+        <translation>Zbirovo ime:</translation>
     </message>
 </context>
 <context>
     <name>RGuiAction</name>
     <message>
-        <location filename="../src/core/RGuiAction.cpp" line="+184"/>
+        <location filename="../src/core/RGuiAction.cpp" line="+186"/>
         <source>Requires selection</source>
-        <translation>Zahteva izbor</translation>
+        <translation>Zahtevan izbor</translation>
     </message>
 </context>
 <context>
@@ -702,7 +708,7 @@
     </message>
     <message>
         <source>Linetype</source>
-        <translation type="vanished">Tip črte</translation>
+        <translation type="vanished">Vrsta črte</translation>
     </message>
     <message>
         <source>Lineweight</source>
@@ -717,7 +723,7 @@
     </message>
     <message>
         <source>By Block</source>
-        <translation type="vanished">Po elementu</translation>
+        <translation type="vanished">Po zbiru</translation>
     </message>
     <message>
         <source>Continuous</source>
@@ -725,39 +731,39 @@
     </message>
     <message>
         <source>Dot</source>
-        <translation type="vanished">Pika</translation>
+        <translation type="vanished">Pikčasto</translation>
     </message>
     <message>
         <source>Dot (small)</source>
-        <translation type="vanished">Pika (majhna)</translation>
+        <translation type="vanished">Pikčasto (gosto)</translation>
     </message>
     <message>
         <source>Dot (large)</source>
-        <translation type="vanished">Pika (velika)</translation>
+        <translation type="vanished">Pikčasto (redko)</translation>
     </message>
     <message>
         <source>Dash</source>
-        <translation type="vanished">Črtica</translation>
+        <translation type="vanished">Črtkano</translation>
     </message>
     <message>
         <source>Dash (small)</source>
-        <translation type="vanished">Črtica (majhna)</translation>
+        <translation type="vanished">Črtkano (gosto)</translation>
     </message>
     <message>
         <source>Dash (large)</source>
-        <translation type="vanished">Črtica (velika)</translation>
+        <translation type="vanished">Črtkano (redko)</translation>
     </message>
     <message>
         <source>Dash Dot</source>
-        <translation type="vanished">Črtica Pika</translation>
+        <translation type="vanished">Črtopično</translation>
     </message>
     <message>
         <source>Dash Dot (small)</source>
-        <translation type="vanished">Črtica Pika (majhna)</translation>
+        <translation type="vanished">Črtopično (gosto)</translation>
     </message>
     <message>
         <source>Dash Dot (large)</source>
-        <translation type="vanished">Črtica Pika (velika)</translation>
+        <translation type="vanished">Črtopično (redko)</translation>
     </message>
     <message>
         <source>Divide</source>
@@ -777,11 +783,11 @@
     </message>
     <message>
         <source>Center (small)</source>
-        <translation type="vanished">Srednjica (majhna)</translation>
+        <translation type="vanished">Srednjica (gosta)</translation>
     </message>
     <message>
         <source>Center (large)</source>
-        <translation type="vanished">Srednjica (velika)</translation>
+        <translation type="vanished">Srednjica (redka)</translation>
     </message>
     <message>
         <source>Border</source>
@@ -789,11 +795,11 @@
     </message>
     <message>
         <source>Border (small)</source>
-        <translation type="vanished">Rob (majhna)</translation>
+        <translation type="vanished">Rob (gosto)</translation>
     </message>
     <message>
         <source>Border (large)</source>
-        <translation type="vanished">Rob (velika)</translation>
+        <translation type="vanished">Rob (redko)</translation>
     </message>
     <message>
         <location filename="../src/core/RLinetype.cpp" line="+48"/>
@@ -808,7 +814,7 @@
     <message>
         <location line="+1"/>
         <source>Metric</source>
-        <translation>Mersko</translation>
+        <translation>Metrično</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -826,7 +832,7 @@
     <message>
         <location line="+1"/>
         <source>By Block</source>
-        <translation>Po elementu</translation>
+        <translation>Po zbiru</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -852,14 +858,14 @@
         <location line="+1"/>
         <location line="+1"/>
         <source>Dash dot</source>
-        <translation>Črtica Pika</translation>
+        <translation>Črtopično</translation>
     </message>
     <message>
         <location line="+2"/>
         <location line="+1"/>
         <location line="+1"/>
         <source>Dashed</source>
-        <translation>Črtica</translation>
+        <translation>Črtkano</translation>
     </message>
     <message>
         <location line="+2"/>
@@ -873,7 +879,7 @@
         <location line="+1"/>
         <location line="+1"/>
         <source>Dot</source>
-        <translation>Pika</translation>
+        <translation>Pikčasto</translation>
     </message>
     <message>
         <location line="+2"/>
@@ -887,12 +893,12 @@
         <location line="+1"/>
         <location line="+1"/>
         <source>Phantom</source>
-        <translation>Fantomska</translation>
+        <translation>Navidezna</translation>
     </message>
     <message>
         <location line="+2"/>
         <source>ISO dash</source>
-        <translation>ISO črtica</translation>
+        <translation>ISO črtkano</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -917,7 +923,7 @@
     <message>
         <location line="+1"/>
         <source>ISO dot</source>
-        <translation>ISO pika</translation>
+        <translation>ISO pikčasta</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -932,7 +938,7 @@
     <message>
         <location line="+1"/>
         <source>ISO dash dot</source>
-        <translation>ISO črtica pika</translation>
+        <translation>ISO črtopično</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -977,7 +983,7 @@
     <message>
         <location line="+1"/>
         <source>Batting</source>
-        <translation>Zbito</translation>
+        <translation>Vijugasta</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -987,7 +993,7 @@
     <message>
         <location line="+1"/>
         <source>Tracks</source>
-        <translation>Sledi</translation>
+        <translation>Tir</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -1002,12 +1008,12 @@
     <message>
         <location line="+2"/>
         <source>Drainage</source>
-        <translation>Drenaža</translation>
+        <translation>Odvodnjavanje</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Drainage Reversed</source>
-        <translation>Drenaža obratna</translation>
+        <translation>Odvodnjavanje obrnjeno</translation>
     </message>
 </context>
 <context>
@@ -1020,7 +1026,7 @@
     <message>
         <location line="+1"/>
         <source>By Block</source>
-        <translation>Po elementu</translation>
+        <translation>Po zbiru</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -1030,7 +1036,7 @@
     <message>
         <location line="+1"/>
         <source>0.00mm</source>
-        <translation>0.00mm (hairline)</translation>
+        <translation>0.00mm</translation>
     </message>
     <message>
         <location line="+1"/>
